/*
    FEARLUS model0-7: BitItem.h
    Copyright (C) 1999-2003  Macaulay Institute

    This file is part of FEARLUS model0-7, an agent-based model of land use
    change.

    FEARLUS model0-7 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model0-7 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*


Interface for the bitItem class. This is just a class to contain an unsigned
long. I've subclassed it off the CreateDrop class in the hope that this will
provide the two facilities the class name implies.

*/

#import <defobj.h>
#import <defobj/Create.h>
#import <random.h>
#import <stdio.h>

@class Interval;

@interface BitItem: CreateDrop {
  unsigned bits;
  int bitsThatCount;
}

-(void)set_Bits: (unsigned)value;
-(unsigned)get_Bits;
-(void)set_Bit: (int)n to: (int)value;
-(int)get_Bit: (int)n;
-(void)toggle_Bit: (int)n;
-(void)set_EachBitTo: (int)value withProbability: (Interval *)prob;
-(unsigned)get_SubBitsFrom: (int)bit1 to: (int)bit2;
-(void)set_ToSubBitsOf: (BitItem *)bits1 from: (int)bit1 to: (int)bit2;
-(int)get_NoOfBits;
+(int)get_MaxBits;
-(int)get_BitsThatCount;
-(void)set_BitsThatCount: (int)value;
-(void)set_ToCopyOf: (BitItem *)bits1;
-(int)set_ToConcatenationOf: (BitItem *)bits1 and: (BitItem *)bits2;
-(void)set_ToParityOf: (BitItem *)bits1 and: (BitItem *)bits2;
-(void)set_ToOROf: (BitItem *)bits1 and: (BitItem *)bits2;
-(void)set_ToXOROf: (BitItem *)b1 and: (BitItem *)b2;
-(int)get_MatchWith: (BitItem *)anItem;
-(void)set_ToCrossoverOf: (BitItem *)bits1 and: (BitItem *)bits2 at: (int)n;
-(void)mutate_WithProbability: (Interval *)prob;
-(int)count_Ones;
-(char *)set_ToString: (char *)aString;
-(void)print_ToFile: (FILE *)fp;
-(void)print_ToString: (char *)aBuffer;
-(void)print_;

@end
