/*
    FEARLUS model0-7: LandManagerHistory.m
    Copyright (C) 1999-2003  Macaulay Institute

    This file is part of FEARLUS model0-7, an agent-based model of land use
    change.

    FEARLUS model0-7 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model0-7 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*


Interface for the LandManagerHistory class.

*/

#import "LandManagerHistory.h"
#import "Interval.h"

@implementation LandManagerHistory

/*

initialiseWithYear

Record all the information required for a single year

*/

-(void)initialiseWithYear: (unsigned)yr
	landParcelsGained: (int)lpg
      neighbourhoodWeight: (Interval *)s
		   wealth: (Interval *)w
		      age: (unsigned)a {
  year = yr;
  parcelsGained = lpg;
  neighbourhoodWeight = s;
  wealth = w;
				// This is safe -- the wealth and weight will
				// have been called by value, and so these will
				// be a copy. Rather than creating new values,
				// and dropping the arguments s and w, we can
				// just transfer the pointers and drop them
				// when this history object is dropped.
  age = a;
}

/*

printToFile

Write a year's data to the file

*/

-(void)printToFile: (FILE *)fp {
  fprintf(fp, "%u\t%d\t%u\t%s\t%s", year, parcelsGained,
	  age, [wealth printf: "%g"], [neighbourhoodWeight printf: "%g"]);
  [Interval printfclean];
}

-(void)drop {
  [wealth drop];
  [neighbourhoodWeight drop];
  [super drop];
}

@end
