/*
    FEARLUS model0-7: ObserverSwarm.h
    Copyright (C) 1999-2003  Macaulay Institute

    This file is part of FEARLUS model0-7, an agent-based model of land use
    change.

    FEARLUS model0-7 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model0-7 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*


Interface for the ObserverSwarm class -- a swarm for probing and graphing and
displaying the model swarm. This is based very heavily on the tutorial
ObserverSwarm class.

*/

#import <simtoolsgui/GUISwarm.h>
#import <space/Object2dDisplay.h>
#import <simtoolsgui.h>
#import <collections.h>
#import <objectbase.h>
#import <analysis.h>
#import <gui.h>
#import <tkobjc/CheckButton.h>
#import <tkobjc/global.h>
#import <activity.h>
#import <sys/types.h>
#import <sys/stat.h>
#import <errno.h>
#import <string.h>
#import <objc/objc-api.h>	// sel_get_name

@class ModelSwarm, EZBar, DBColormap, Parameter, Reporter, StrategyColourKey;

@interface ObserverSwarm: GUISwarm {
  int displayFrequency;
  // Maybe there should be some variables for handling which displays to do
  Parameter *parameter;
  Reporter *reporter;
  unsigned writeHistoryFrequency;
  unsigned seed;
  BOOL dumpHistory;
  BOOL saveDumpedHistory;

  id displayActions;
  id displaySchedule;
  id initialSchedule;
  id historySchedule;
  id reporterSchedule;

  ModelSwarm *modelSwarm;

  char *historyFileName;

  BOOL showStrategyColourKey;
  BOOL showUseRaster;
  BOOL showLPBitStringRaster;
  BOOL showLPBitStringDiffs;
  BOOL showManagerRaster;
  BOOL showSubPopRaster;
  BOOL showStrategyRaster;
  BOOL showUseChangeRaster;
  BOOL showManagerChangeRaster;
  BOOL showParcelsOwnedGraph;
  BOOL showYieldGraph;
  BOOL showPopulationGraph;
  BOOL showUseGraph;
  BOOL showWealthGraph;
  BOOL showAgeGraph;
  BOOL showUseBar;
  BOOL showNWeightDist;
  BOOL showThresholdDist;
  BOOL showImitProbDist;
  BOOL showMemoryGraph;

  char *lpBitStringTitle;
  int lpBitStringBit;
  DBColormap *colorMap;
  StrategyColourKey *legend;
  id <Colormap> strategyCMap;

  id <ZoomRaster> envRaster;
  id <ZoomRaster> landUseChangeRaster;
  id <ZoomRaster> landMgrChangeRaster;
  id <ZoomRaster> landMgrRaster;
  id <ZoomRaster> subPopRaster;
  id <ZoomRaster> strategyRaster;
  id <ZoomRaster> lpBitStringRaster;

  id <EZGraph> parcelsOwnedGraph;
  id <EZGraph> yieldGraph;
  id <EZGraph> landMgrPopGraph;
  id <EZGraph> landUseGraph;
  id <EZGraph> wealthGraph;
  id <EZGraph> ageGraph;
  id <EZGraph> memoryGraph;

  int nHistogramBins;
  int zoomSize;
  id <List> nbrwgtDists;
  id <List> happyThreshDists;
  id <List> imitProbDists;
  id <List> widgetList;

  id <ActionTo> resizeGraphsAction;

  id <Canvas> obsFrame;
  id <CheckButton> testCheck;

  EZBar *landUseBar;

  id <Object2dDisplay> landUseChangeDisplay;
  id <Object2dDisplay> landMgrChangeDisplay;
  id <Object2dDisplay> landParcelDisplay;
  id <Object2dDisplay> parcelBoundaryDisplay;
  id <Object2dDisplay> landMgrDisplay;
  id <Object2dDisplay> subPopDisplay;
  id <Object2dDisplay> strategyDisplay;
  id <Object2dDisplay> parcelNbrDisplay;
  id <Object2dDisplay> lpBitStringDisplay;
}

+createBegin: (id)z;
-createEnd;
-(void)buildGUIObjects;
-buildReporter;
-buildObjects;
-buildActions;
-toggleMgrNeighbourhoodOfX: (int)x Y: (int)y;
-incLandParcelBitDisplayed;
-decLandParcelBitDisplayed;
-togglePhysNeighbourhoodOfX: (int)x Y: (int)y;
-(void)populateGraphs;
-(double)countScratchZone;
-(double)countObserverZone;
-(double)countModelZone;
-(double)countHistoryZone;
-(double)countIntervalZone;
-(double)countIntervalStack;
-(unsigned long long)countZone: (id <Zone>)z;
-activateIn: (id)swarmContext;
-(void)setSpecifiedSeed: (unsigned)value;
-writeHistory;
-(void)writeHistoryToFile: (const char *)fileName;
-(void)drop;

@end
