/*
    FEARLUS model0-7: StrategyType.h
    Copyright (C) 1999-2003  Macaulay Institute

    This file is part of FEARLUS model0-7, an agent-based model of land use
    change.

    FEARLUS model0-7 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model0-7 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*


An object to store the data for a particular strategy type. This class is used
by the StrategySelector class to store the data for each strategy being used.
This consists of a set of probabilities for the strategy type being chosen
for a particular context, which is one of: above breakEvenThreshold, below
breakEvenThreshold non-imitative, below breakEvenThreshold imitative, or
initial. Certain strategies are also barred from use in particular contexts,
according to the protocol they follow. E.g. an Imitative strategy cannot have a
probability for use as a below breakEvenThreshold non-imitative strategy, and
a Historical strategy cannot have a probability for use as an initial strategy.

*/

#import <objectbase/SwarmObject.h>
#import <objc/objc-api.h>		// class_get_class_name
// #import <tkobjc/Frame.h>
// #import <tkobjc/Label.h>
#import "Strategy.h"

@interface StrategyType: SwarmObject {
  Class strategyClass;
  double initialProb;
  double aboveProb;
  double belowNonImitativeProb;
  double belowImitativeProb;
  // GUI stuff (like it'll work, ha ha!)
  //  BOOL createdGUI;
  //id frame;			// Should be id <Frame>, but compiler whinges
				// that the packWith: method isn't supported 
				// -- but it is there...
  // id <VarProbe> initialProbe, aboveProbe, belowNonImitativeProbe,
  //   belowImitativeProbe;
  // id initialEntry, aboveEntry, belowNonImitativeEntry,
  //  belowImitativeEntry;
  // id <Label> classLabel;
}

+create: aZone forStrategyClass: (Class)aStrategyClass;
-(void)setInitialProb: (double)value;
-(void)setAboveProb: (double)value;
-(void)setBelowNonImitativeProb: (double)value;
-(void)setBelowImitativeProb: (double)value;
-(Class)getStrategyClass;
-(const char *)getStrategyClassName;
-(double)getInitialProb;
-(double)getAboveProb;
-(double)getBelowNonImitativeProb;
-(double)getBelowImitativeProb;
//-(void)createGUIStuffWithParent: (id <Frame>)f;
//-(void)pack;
//-(unsigned)getClassWidth;
//-(unsigned)getAboveWidth;
//-(unsigned)getBelowNonWidth;
//-(unsigned)getBelowWidth;
//-(unsigned)getInitWidth;
//-(void)setWidthsClass: (unsigned)wClass
//		above: (unsigned)wAbove
//	     belowNon: (unsigned)wBelowNon
//		below: (unsigned)wBelow
//		 init: (unsigned)wInit;
-(void)drop;

@end
